summaryrefslogtreecommitdiff
path: root/indra/llmessage
diff options
context:
space:
mode:
authorWilliam Todd Stinson <stinson@lindenlab.com>2012-11-08 12:35:15 -0800
committerWilliam Todd Stinson <stinson@lindenlab.com>2012-11-08 12:35:15 -0800
commitc4eaaa3d6a08330863119d550d365315ba7526bb (patch)
treef0bae909425bb8ddd96d6fb731e40dd2237d6a18 /indra/llmessage
parentfa85e16d63b09326b9facb4850d50cd163f87bc7 (diff)
CHUI-484: Updating the code to rather than refer to it as Busy Mode, it now refers to it as Do Not Disturb mode.
Diffstat (limited to 'indra/llmessage')
-rw-r--r--indra/llmessage/llinstantmessage.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/indra/llmessage/llinstantmessage.h b/indra/llmessage/llinstantmessage.h
index 12e4e79475..db4a38ea9e 100644
--- a/indra/llmessage/llinstantmessage.h
+++ b/indra/llmessage/llinstantmessage.h
@@ -115,8 +115,8 @@ enum EInstantMessage
// viewer, since you can't IM an object yet.
IM_FROM_TASK = 19,
- // sent an IM to a busy user, this is the auto response
- IM_BUSY_AUTO_RESPONSE = 20,
+ // sent an IM to a do not disturb user, this is the auto response
+ IM_DO_NOT_DISTURB_AUTO_RESPONSE = 20,
// Shows the message in the console and chat history
IM_CONSOLE_AND_CHAT_HISTORY = 21,